==> dcl_0.9.2.orig.tar.gz: dcl/inc/class.boAccounts.inc.php <==
<?php
/*
 * $Id: class.boAccounts.inc.php,v 1.2.2.1 2002/02/15 02:49:53 mdean Exp $
 *
 * Double Choco Latte - Source Configuration Management System
 * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Select License Info from the Help menu to view the terms and conditions of this license.
 */

LoadStringResource('bo');

class boAccounts
{
	function add()
	{
		commonHeader();
		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$obj = CreateObject('dcl.htmlAccounts');
		$obj->ShowEntryForm();
	}

	function dbadd()
	{
		commonHeader();
		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$obj = CreateObject('dcl.dbAccounts');
		$obj->Connect();
		$obj->InitFromGlobals();
		if ($obj->Add() != -1)
		{
			print('<center>');
			PrintWithChocoFont(sprintf(STR_BO_ACCOUNTSUCCESS, $obj->name));
			print('</center>');
		}
	}

	function modify()
	{
		commonHeader();
		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$obj = CreateObject('dcl.dbAccounts');
		$obj->Connect();
		$obj->Load($GLOBALS['id']);

		$objHTML = CreateObject('dcl.htmlAccounts');
		$objHTML->ShowEntryForm($obj);
	}

	function dbmodify()
	{
		commonHeader();
		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$obj = CreateObject('dcl.dbAccounts');
		$obj->Connect();
		$obj->InitFromGlobals();
		$obj->Edit();
		$objHTML = CreateObject('dcl.htmlAccounts');
		$objHTML->ExecuteSearch('Name', $obj->name);
	}

	function delete()
	{
		commonHeader();
		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$obj = CreateObject('dcl.dbAccounts');
		$obj->Connect();
		$obj->Load($GLOBALS['id']);
		ShowDeleteYesNo('Account', 'boAccounts.dbdelete', $obj->id, $obj->name);
	}

	function dbdelete()
	{
		global $dcl_domain_info, $dcl_domain;

		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$classSubName = 'Accounts';

		commonHeader();
		$obj = CreateObject('dcl.db' . $classSubName);
		$obj->connect();
		$obj->Load($GLOBALS['id']);

		$objKey = new dclDB; // Don't really need anything fancy, 'spose...
		$noref = true;
		$objKey->connect($obj->conn);
		while ((list($table, $field) = each($obj->foreignKeys)) && $noref)
		{
			if (is_array($field)) // More than one field in here references this key
			{
				while ((list($dummykey, $onefield) = each($field)) && $noref)
				{
					$obj->Query("SELECT $onefield FROM $table WHERE $onefield=" . $GLOBALS['id']);
					if ($obj->next_record())
						$noref = false;
				}
			}
			else
			{
				$obj->Query("SELECT $field FROM $table WHERE $field=" . $GLOBALS['id']);
				if ($obj->next_record())
					$noref = false;
			}
		}

		if ($noref)
		{
			$obj->Delete();
			print(STR_BO_DELETED);
		}
		else
		{
			$obj->SetActive(false);
			print(STR_BO_DEACTIVATED);
		}

		$objHTML = CreateObject('dcl.html' . $classSubName);
		$objHTML->ExecuteSearch('Name', $obj->name);
	}

	function search()
	{
		commonHeader();
		$obj = CreateObject('dcl.htmlAccounts');
		$obj->ShowSearchForm();
	}

	function executesearch()
	{
		commonHeader();
		$obj = CreateObject('dcl.htmlAccounts');
		$obj->ExecuteSearch($GLOBALS['searchfield'], $GLOBALS['searchtext']);
	}
}
?>

==> dcl_0.9.4.4.orig.tar.gz: dcl/inc/class.boAccounts.inc.php <==
<?php
/*
 * $Id: class.boAccounts.inc.php,v 1.2.2.1.2.3 2003/05/30 03:56:39 mdean Exp $
 *
 * Double Choco Latte - Source Configuration Management System
 * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Select License Info from the Help menu to view the terms and conditions of this license.
 */

LoadStringResource('bo');

class boAccounts
{
	function add()
	{
		commonHeader();
		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$obj = CreateObject('dcl.htmlAccounts');
		$obj->ShowEntryForm();
	}

	function dbadd()
	{
		commonHeader();
		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$obj = CreateObject('dcl.dbAccounts');
		$obj->Connect();
		$obj->InitFromGlobals();

		if ($obj->HasDuplicates($obj->short, $obj->name))
		{
			$oHTML = CreateObject('dcl.htmlAccounts');
			$oHTML->ShowDuplicates($obj->short, $obj->name);
			$oHTML->ShowEntryForm($obj);

			return;
		}

		$obj->InitFromGlobals();
		if ($obj->Add() != -1)
		{
			$o = CreateObject('dcl.htmlAccounts');
			$o->ShowDetail($obj->id);
		}
	}

	function modify()
	{
		commonHeader();
		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$obj = CreateObject('dcl.dbAccounts');
		$obj->Connect();
		$obj->Load($GLOBALS['id']);

		$objHTML = CreateObject('dcl.htmlAccounts');
		$objHTML->ShowEntryForm($obj);
	}

	function dbmodify()
	{
		commonHeader();
		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$obj = CreateObject('dcl.dbAccounts');
		$obj->Connect();
		$obj->InitFromGlobals();
		$obj->Edit();
		$objHTML = CreateObject('dcl.htmlAccounts');
		$objHTML->ShowDetail($obj->id);
	}

	function delete()
	{
		commonHeader();
		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$obj = CreateObject('dcl.dbAccounts');
		$obj->Connect();
		$obj->Load($GLOBALS['id']);
		ShowDeleteYesNo('Account', 'boAccounts.dbdelete', $obj->id, $obj->name);
	}

	function dbdelete()
	{
		global $dcl_domain_info, $dcl_domain;

		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$classSubName = 'Accounts';

		commonHeader();
		$obj = CreateObject('dcl.db' . $classSubName);
		$obj->connect();
		$obj->Load($GLOBALS['id']);

		$objKey = new dclDB; // Don't really need anything fancy, 'spose...
		$noref = true;
		$objKey->connect($obj->conn);
		while ((list($table, $field) = each($obj->foreignKeys)) && $noref)
		{
			if (is_array($field)) // More than one field in here references this key
			{
				while ((list($dummykey, $onefield) = each($field)) && $noref)
				{
					$obj->Query("SELECT $onefield FROM $table WHERE $onefield=" . $GLOBALS['id']);
					if ($obj->next_record())
						$noref = false;
				}
			}
			else
			{
				$obj->Query("SELECT $field FROM $table WHERE $field=" . $GLOBALS['id']);
				if ($obj->next_record())
					$noref = false;
			}
		}

		if ($noref)
		{
			$obj->Delete();
			print(STR_BO_DELETED);
		}
		else
		{
			$obj->SetActive(false);
			print(STR_BO_DEACTIVATED);
		}

		$objHTML = CreateObject('dcl.html' . $classSubName);
		$objHTML->ExecuteSearch('Name', $obj->name);
	}

	function search()
	{
		commonHeader();
		$obj = CreateObject('dcl.htmlAccounts');
		$obj->ShowSearchForm();
	}

	function executesearch()
	{
		commonHeader();
		$obj = CreateObject('dcl.htmlAccounts');
		$obj->ExecuteSearch($GLOBALS['searchfield'], $GLOBALS['searchtext']);
	}
}
?>
